@@ -16,6 +16,9 @@ class Mdisk:
         self.__api_key = api_key
         self.__base_url = 'https://diskuploader.mypowerdisk.com/v1/tp/cp'
 
+        if not self.__api_key:
+            raise Exception("API key not provided")
+
 
     async def convert(self, link:str, silently_fail:bool | None =False) -> str:
         """
@@ -43,7 +46,7 @@ class Mdisk:
             except requests.exceptions.ConnectionError as errc:
                 print("Error Connecting: ",errc)
             except Exception as e:
-                return await self.__error_handler(url=e, silently_fail=silently_fail, exception=Exception)
+                return await self.__error_handler(url=link, silently_fail=silently_fail, exception=Exception)
         else: 
             return await self.__error_handler(url=link, silently_fail=silently_fail, exception=LinkInvalid)
 
@@ -76,7 +79,7 @@ class Mdisk:
         defaults to True
         :return: A text of converted links
         """
-        links = re.findall(r'https?://mdisk.me[^\s"*<>()]+', text)
+        links = re.findall(r'https?://mdisk.me[^\s`!()\[\]{};:".,<>?«»“”‘’]+', text)
         converted_links = await self.bulk_convert(links, silently_fail=silently_fail)
 
         for i, mdisk_link in enumerate(converted_links):
@@ -146,7 +149,7 @@ class Mdisk:
         return link.split('/')[-1]
 
 
-    async def __error_handler(self, url:str, silently_fail:bool, exception=Exception) -> Any | Exception:
+    async def __error_handler(self, url:str, silently_fail:bool, exception=Exception, message="Some error occurred during converting: %s") -> Any | Exception:
         """
         If the URL is valid, return it. If it's not, return it or raise an exception, depending on the value
         of the `silently_fail` parameter
@@ -162,7 +165,7 @@ class Mdisk:
         if silently_fail:
             return url
         else:
-            raise exception(url)
+            raise exception(message % url)
 
 
     @staticmethod
